Modoboa documentation — Modoboa 1.7.4 documentation

### Navigation

- index
- next |
- Modoboa 1.7.4 documentation »

# Modoboa documentation

## Overview

Modoboa is a mail hosting and management platform including a modern and simplified Web User Interface designed to work with Postfix and Dovecot.

It is extensible by nature and comes with a lot of additional extensions:

Name | Description | Documentation
--- | --- | ---
modoboa-amavis | A frontend for Amavis | https://modoboa-amavis.readthedocs.io
modoboa-dmarc | A set of tools to use DMARC | https://github.com/modoboa/modoboa-dmarc
modoboa-imap-migration | Migrate mailboxes from an existing server using IMAP (and offlineimap) | https://github.com/modoboa/modoboa-imap-migration
modoboa-pdfcredentials | Generate PDF documents containing account credentials | https://github.com/modoboa/modoboa-pdfcredentials
modoboa-pfxadmin-migrate | A tool to migrate from Postfixadmin | https://github.com/modoboa/modoboa-pfxadmin-migrate
modoboa-postfix-autoreply | Away message editor (postfix compatible) | https://modoboa-postfix-autoreply.readthedocs.io
modoboa-radicale | A frontend for Radicale | https://modoboa-radicale.readthedocs.io
modoboa-sievefilters | A Sieve filters (rules) editor | https://modoboa-sievefilters.readthedocs.io
modoboa-stats | Graphical statistics (message traffic and more) | https://modoboa-stats.readthedocs.io
modoboa-webmail | A simple webmail | https://modoboa-webmail.readthedocs.io

## Table of contents

- Installation
- Upgrade
- Configuration
- Moving to Modoboa
- REST API
- How to contribute
- Contributors

### Navigation

- index
- next |
- Modoboa 1.7.4 documentation »